aboutsummaryrefslogtreecommitdiffstats
path: root/modules/communication/neomutt/assertions.nix
diff options
context:
space:
mode:
authorArpit Chakladar <arpitchakladar+git@gmail.com>2026-07-26 23:28:11 +0530
committerArpit Chakladar <arpitchakladar+git@gmail.com>2026-07-26 23:28:11 +0530
commit6910400bb38bb69a9e81b932b01fa51802cb0c47 (patch)
treed291a7c6e18b9b669b9a405cad9cfc5ba10547ee /modules/communication/neomutt/assertions.nix
parentb93a73ba98e94cbb971dce6554c7c55bce517c0e (diff)
downloadhome-manager-config-6910400bb38bb69a9e81b932b01fa51802cb0c47.tar.gz
home-manager-config-6910400bb38bb69a9e81b932b01fa51802cb0c47.zip
feat: replace w3m with chawan for HTML rendering and web browsing
- Create web.chawan module with enable/package options, kitty desktop entry, and programs.chawan.settings (buffer.images=true, display.image-mode=auto) - Update neomutt macros, mailcap, and assertions from w3m to chawan - Switch waybar window-rewrite and workspace icon from W3M to Chawan - Drop web/w3m module
Diffstat (limited to 'modules/communication/neomutt/assertions.nix')
-rw-r--r--modules/communication/neomutt/assertions.nix8
1 files changed, 4 insertions, 4 deletions
diff --git a/modules/communication/neomutt/assertions.nix b/modules/communication/neomutt/assertions.nix
index c4ce62a..5fad5c9 100644
--- a/modules/communication/neomutt/assertions.nix
+++ b/modules/communication/neomutt/assertions.nix
@@ -1,4 +1,4 @@
# Assertions - Validates neomutt dependencies (less, bat, kitty, w3m) are enabled
{ config, ... }:
{
assertions = [
@@ -24,10 +24,10 @@
'';
}
{
- assertion = !config.communication.neomutt.enable || config.web.w3m.enable;
+ assertion = !config.communication.neomutt.enable || config.web.chawan.enable;
message = ''
- communication.neomutt is enabled but web.w3m.enable is not.
- neomutt uses w3m for HTML email rendering. Please enable web.w3m.
+ communication.neomutt is enabled but web.chawan.enable is not.
+ neomutt uses chawan for HTML email rendering. Please enable web.chawan.
'';
}
];
@@ -1,4 +1,4 @@
-# Assertions - Validates neomutt dependencies (less, bat, kitty, w3m) are enabled
+# Assertions - Validates neomutt dependencies (less, bat, kitty, chawan) are enabled
{ config, ... }:
{